/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.fieldplan;

import java.io.IOException;
import java.io.ObjectInputStream;
import java.io.ObjectOutputStream;
import java.util.ArrayList;
import java.util.List;
import org.openide.filesystems.FileObject;
import org.openide.filesystems.FileUtil;
import org.openide.loaders.DataFolder;
import org.openide.loaders.DataObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.NbBundle.Messages;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
@Messages({"FieldPlan name prefix=Field plan-"})
@ServiceProvider(service=FieldPlanManager.class)
public class FieldPlanManagerImpl implements FieldPlanManager {

    /**
     * 
     * @param harvestYear
     * @param farmFolder
     * @return 
     */
    @Override
    public FieldPlan addFieldPlan(Integer harvestYear, FileObject farmFolder) {
        FieldPlan fieldPlan = null;
        try {
            fieldPlan = new FieldPlan();
            fieldPlan.setHarvestYear(harvestYear);
            fieldPlan.setName(Bundle.FieldPlan_name_prefix() + harvestYear.toString());
            String fieldPlanFolderName = FileUtil.findFreeFolderName(farmFolder, fieldPlan.getName());
            FileObject fieldPlanFolder = farmFolder.createFolder(fieldPlanFolderName);
            save(fieldPlan, fieldPlanFolder.createData(fieldPlanFolderName, "fpn"));
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return fieldPlan;
    }
    
    /**
     * 
     * @param fieldPlan
     * @param fileObject 
     */
    @Override
    public void save(FieldPlan fieldPlan, FileObject fileObject) {
        try (ObjectOutputStream oos = new ObjectOutputStream(fileObject.getOutputStream())) {
            oos.writeObject(fieldPlan);
        } catch (IOException ex) {
            Exceptions.printStackTrace(ex);
        }
    }
    
    /**
     * loads a fieldplan from a fileobject
     * 
     * @param fileObject
     * @return 
     */
    @Override
    public FieldPlan load(FileObject fileObject) {
        FieldPlan fieldPlan = null;
        try (ObjectInputStream ois = new ObjectInputStream(fileObject.getInputStream())) {
            fieldPlan = (FieldPlan) ois.readObject();
        } catch (ClassNotFoundException | IOException ex) {
            Exceptions.printStackTrace(ex);
        }
        return fieldPlan;
    }

}
