/*
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 * 
 * Licensed under the Eclipse Public License - v 1.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * 
 * http://www.eclipse.org/legal/epl-v10.html
 * 
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package nl.cloudfarming.client.farm.fieldplan;

import java.awt.Image;
import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Logger;
import javax.swing.Action;
import org.openide.filesystems.FileLock;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataFolder;
import org.openide.loaders.DataObject;
import org.openide.nodes.FilterNode;
import org.openide.nodes.Node;
import org.openide.util.Exceptions;
import org.openide.util.ImageUtilities;
import org.openide.util.actions.SystemAction;

/**
 *
 * @author Timon Veenstra <monezz@gmail.com>
 */
public class FieldPlanNode extends FilterNode {

    private DataObject fieldPlanObject;
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.farm.fieldplan");

    public FieldPlanNode(DataFolder dataFolder) {
        super(dataFolder.getNodeDelegate(), new ProxyChildren(dataFolder.getNodeDelegate()));
        for (DataObject dataObject : dataFolder.getChildren()) {
            if (dataObject.getName().equals(dataFolder.getName())) {
                fieldPlanObject = dataObject;
            }
        }
        // try to fix if broken
        if (fieldPlanObject == null){
            LOGGER.warning("The field plan data file probably has a name that differs from the folder, attempting to rename it. This indicated a bug elswhere!");
            for (DataObject dataObject : dataFolder.getChildren()) {
                FileObject fo = dataObject.getPrimaryFile();
                if (FieldPlanDataObject.EXT.equals(fo.getExt())){
                    try {
                        FileLock lock = fo.lock();
                        fo.rename(lock, dataFolder.getName(), FieldPlanDataObject.EXT);
                        lock.releaseLock();
                    } catch (IOException ex) {
                        Exceptions.printStackTrace(ex);
                    }
                }
            }
        }
        assert fieldPlanObject != null;
    }

    @Override
    public Image getIcon(int type) {
        return ImageUtilities.loadImage(FieldPlanDataObject.ICON_BASE);
    }

    @Override
    public Image getOpenedIcon(int type) {
        return getIcon(type);
    }

    //FIXME add rename listener to also rename the fieldplan fpn file
    @Override
    public Action[] getActions(boolean context) {
        Action[] nodeActions = new Action[1];
        nodeActions[0] = fieldPlanObject.getNodeDelegate().getPreferredAction();
        return nodeActions;
    }

    public static class ProxyChildren extends FilterNode.Children {

        public ProxyChildren(Node owner) {
            super(owner);
        }

        @Override
        protected Node[] createNodes(Node object) {
            List<Node> result = new ArrayList<Node>();
            for (Node node : super.createNodes(object)) {
                if (accept(node)) {
                    result.add(node);
                }
            }
            return result.toArray(new Node[0]);
        }

        private boolean accept(Node node) {
            //TODO accept other content like production units and only filter the fieldplan file
            return false;
        }
    }
}
